

class Overload_Joke():
    
    def __init__(self):
        self.phrase = "phrase"
        
    def joke(self):
        return ("Why this not work?")

class Autism():

    def brah(self):
        return("wtf") 